OC.L10N.register(
    "settings",
    {
    "Authentication error" : "Ralat pengesahan",
    "__language_name__" : "_nama_bahasa_",
    "Language changed" : "Bahasa diubah",
    "Invalid request" : "Permintaan tidak sah",
    "Disable" : "Nyahaktif",
    "Enable" : "Aktif",
    "Delete" : "Padam",
    "Groups" : "Kumpulan",
    "never" : "jangan",
    "Log" : "Log",
    "Login" : "Log masuk",
    "Server address" : "Alamat pelayan",
    "Profile picture" : "Gambar profil",
    "Cancel" : "Batal",
    "Email" : "Email",
    "Your email address" : "Alamat emel anda",
    "Password" : "Kata laluan",
    "Unable to change your password" : "Gagal mengubah kata laluan anda ",
    "Current password" : "Kata laluan semasa",
    "New password" : "Kata laluan baru",
    "Change password" : "Ubah kata laluan",
    "Language" : "Bahasa",
    "Help translate" : "Bantu terjemah",
    "Name" : "Nama",
    "Username" : "Nama pengguna",
    "Personal" : "Peribadi",
    "Admin" : "Admin",
    "Error" : "Ralat",
    "Create" : "Buat",
    "Default Quota" : "Kuota Lalai",
    "Other" : "Lain",
    "Quota" : "Kuota"
},
"nplurals=1; plural=0;");
